==> el-2.28.1.zip: el/public.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%d attachments'] = '%d συνημμένα';
L10n::$locales['%d comments'] = '%d σχόλια';
L10n::$locales['%d trackbacks'] = '%d ίχνη';
L10n::$locales['%s reactions'] = '%s αντιδράσεις';
L10n::$locales['Access to content'] = 'Πρόσβαση στο περιεχόμενο';
L10n::$locales['Add a comment'] = 'Προσθέστε ένα σχόλιο';
L10n::$locales['Add ping'] = 'Προσθήκη ping';
L10n::$locales['Additionnal style directives'] = 'Οδηγίες πρόσθετου στυλ';
L10n::$locales['All keywords'] = 'Όλες οι λέξεις κλειδιά';
L10n::$locales['Archives'] = 'Αρχειοθέτηση';
L10n::$locales['Attachments'] = 'Συνημμένα';
L10n::$locales['Best of me'] = 'Καλύτερο από μένα';
L10n::$locales['Blog info'] = 'Πληροφορίες ιστολογίου';
L10n::$locales['Blog menu'] = 'μενού ιστολογίου';
L10n::$locales['By'] = 'Από';
L10n::$locales['By category'] = 'Κατά κατηγορία';
L10n::$locales['By date'] = 'Κατά ημερομηνία';
L10n::$locales['By tag'] = 'Με ετικέτα';
L10n::$locales['Categories'] = 'Κατηγορίες';
L10n::$locales['Comment'] = 'Σχόλιο';
L10n::$locales['Comments'] = 'Σχόλια';
L10n::$locales['Comments can be formatted using a simple wiki syntax.'] = 'Σχόλια μπορούν να μορφοποιηθούν χρησιμοποιώντας μια απλή σύνταξη wiki.';
L10n::$locales['Comments feed'] = 'Ροή σχολίων';
L10n::$locales['Continue reading'] = 'Συνέχεια ανάγνωσης';
L10n::$locales['Document not found'] = 'Το έγγραφο δεν βρέθηκε';
L10n::$locales['Email address'] = 'Διεύθυνση ηλεκτρονικού ταχυδρομείου';
L10n::$locales['Email address is not valid'] = 'Η διεύθυνση ηλεκτρονικού ταχυδρομείου δεν είναι έγκυρη';
L10n::$locales['Entries feed'] = 'Τροφοδοσία καταχωρήσεων';
L10n::$locales['Explore archives'] = 'Εξερεύνηση αρχείων';
L10n::$locales['Extra menu'] = 'Extra menu';
L10n::$locales['From'] = 'Από';
L10n::$locales['FromDay'] = 'FromDay';
L10n::$locales['Go to homepage'] = 'Μετάβαση στην αρχική σελίδα';
L10n::$locales['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML κωδικός εμφανίζεται ως κείμενο και διευθύνσεις web μετατρέπονται αυτόματα.';
L10n::$locales['Home'] = 'Αρχική';
L10n::$locales['In'] = 'Σε';
L10n::$locales['Languages'] = 'Γλώσσες';
L10n::$locales['Links'] = 'Σύνδεσμοι';
L10n::$locales['Name or nickname'] = 'Όνομα ή ψευδώνυμο';
L10n::$locales['Next entry:'] = 'Επόμενη καταχώρηση:';
L10n::$locales['On'] = 'Ενεργό';
L10n::$locales['Page top'] = 'Κορυφή σελίδας';
L10n::$locales['Pagination'] = 'Σελιδοποίηση';
L10n::$locales['Password needed'] = 'Απαιτείται κωδικός πρόσβασης';
L10n::$locales['Password:'] = 'Κωδικός:';
L10n::$locales['Permalink'] = 'Permalink';
L10n::$locales['Powered by %s'] = 'Τροφοδοτείται από %s';
L10n::$locales['Preview'] = 'Προεπισκόπηση';
L10n::$locales['Previous entry:'] = 'Προηγούμενη καταχώριση:';
L10n::$locales['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'RSS feed είναι μια δωρεάν περίληψη ιστολογίου. Παρέχει περιεχόμενο (δημοσιεύσεις ή σχόλια) ή περιλήψεις περιεχομένου, μαζί με συνδέσμους προς τις πλήρεις εκδόσεις και άλλα μεταδεδομένα. Τα τελευταία δημοσιευμένα στοιχεία μπορούν να διαβαστούν από το αγαπημένο σας RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.';
L10n::$locales['Read'] = 'Ανάγνωση';
L10n::$locales['Remember me on this blog'] = 'Να με θυμάσαι σε αυτό το blog';
L10n::$locales['Required field'] = 'Απαιτούμενο πεδίο';
L10n::$locales['Search'] = 'Αναζήτηση';
L10n::$locales['Send'] = 'Αποστολή';
L10n::$locales['Simply copy the following URL into your aggregator:'] = 'Απλά αντιγράψτε το ακόλουθο URL στον συγκεντρωτή σας:';
L10n::$locales['Subcategories'] = 'Υποκατηγορίες';
L10n::$locales['Subscribe'] = 'Εγγραφή';
L10n::$locales['Subscribe to'] = 'Εγγραφή σε';
L10n::$locales['Suggestions:'] = 'Προτείνες:';
L10n::$locales['The document you are looking for does not exist.'] = 'Το έγγραφο που ψάχνετε δεν υπάρχει.';
L10n::$locales['The list of recents posts is available'] = 'Η λίστα των πρόσφατων δημοσιεύσεων είναι διαθέσιμη';
L10n::$locales['They posted on the same topic'] = 'Δημοσίευσαν στο ίδιο θέμα';
L10n::$locales['This blog\'s comments Atom feed'] = 'Σχόλια αυτού του ιστολογίου';
L10n::$locales['This category\'s comments Atom feed'] = 'Σχόλια αυτής της κατηγορίας Ροή Atom';
L10n::$locales['This category\'s entries Atom feed'] = 'Οι καταχωρήσεις αυτής της κατηγορίας Atom';
L10n::$locales['This post\'s comments Atom feed'] = 'Σχόλια αυτής της ανάρτησης';
L10n::$locales['This post\'s comments feed'] = 'Ροή σχολίων αυτής της ανάρτησης';
L10n::$locales['To content'] = 'Προς περιεχόμενο';
L10n::$locales['To menu'] = 'Στο μενού';
L10n::$locales['To search'] = 'Για αναζήτηση';
L10n::$locales['Trackback URL'] = 'Url Παρακολούθησης';
L10n::$locales['URL you\'ve tried has typos, or the page has been deleted or moved.'] = 'URL που δοκιμάσατε έχει typos, ή η σελίδα έχει διαγραφεί ή μετακινηθεί.';
L10n::$locales['Use search form'] = 'Χρήση φόρμας αναζήτησης';
L10n::$locales['Website'] = 'Ιστοσελίδα';
L10n::$locales['What is an RSS feed?'] = 'Τι είναι ένα RSS feed?';
L10n::$locales['You must give a password to access this area.'] = 'Πρέπει να δώσετε έναν κωδικό πρόσβασης για να αποκτήσετε πρόσβαση σε αυτήν την περιοχή.';
L10n::$locales['You must provide a comment'] = 'Πρέπει να δώσετε ένα σχόλιο';
L10n::$locales['You must provide a valid email address.'] = 'Πρέπει να δώσετε μια έγκυρη διεύθυνση email.';
L10n::$locales['You must provide an author name'] = 'Πρέπει να δώσετε ένα όνομα συγγραφέα';
L10n::$locales['Your comment'] = 'Το σχόλιό σας';
L10n::$locales['Your comment has been published.'] = 'Το σχόλιό σας έχει δημοσιευτεί.';
L10n::$locales['Your comment has been submitted and will be reviewed for publication.'] = 'Το σχόλιό σας έχει υποβληθεί και θα επανεξεταστεί για δημοσίευση.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Η αναζήτησή σας για <em>%1$s</em> επέστρεψε <strong>%2$s</strong> αποτέλεσμα.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Η αναζήτησή σας για <em>%1$s</em> επέστρεψε <strong>%2$s</strong> αποτελέσματα.';
L10n::$locales['Your search for <em>%1$s</em> returned no result.'] = 'Η αναζήτησή σας για <em>%1$s</em> δεν επέστρεψε κανένα αποτέλεσμα.';
L10n::$locales['by'] = 'από';
L10n::$locales['here'] = 'εδώ';
L10n::$locales['in'] = 'σε';
L10n::$locales['next entries'] = 'επόμενες καταχωρήσεις';
L10n::$locales['no attachments'] = 'δεν υπάρχουν συνημμένα';
L10n::$locales['no comments'] = 'κανένα σχόλιο';
L10n::$locales['no reactions'] = 'δεν υπάρχουν αντιδράσεις';
L10n::$locales['no trackbacks'] = 'δεν υπάρχουν ίχνη';
L10n::$locales['of'] = 'από';
L10n::$locales['on'] = 'ενεργό';
L10n::$locales['one attachment'] = 'ένα συνημμένο';
L10n::$locales['one comment'] = 'ένα σχόλιο';
L10n::$locales['one reaction'] = 'μία αντίδραση';
L10n::$locales['one trackback'] = 'ένα trackback';
L10n::$locales['optional'] = 'προαιρετικό';
L10n::$locales['page'] = 'σελίδα';
L10n::$locales['preview'] = 'προεπισκόπηση';
L10n::$locales['previous entries'] = 'προηγούμενες καταχωρήσεις';
L10n::$locales['reactions'] = 'αντιδράσεις';
L10n::$locales['send'] = 'αποστολή';
L10n::$locales['toDay'] = 'toDay';

==> el-2.29.zip: el/public.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%d attachments'] = '%d συνημμένα';
L10n::$locales['%d comments'] = '%d σχόλια';
L10n::$locales['%d trackbacks'] = '%d ίχνη';
L10n::$locales['%s reactions'] = '%s αντιδράσεις';
L10n::$locales['Access to content'] = 'Πρόσβαση στο περιεχόμενο';
L10n::$locales['Add a comment'] = 'Προσθέστε ένα σχόλιο';
L10n::$locales['Add ping'] = 'Προσθήκη ping';
L10n::$locales['Additionnal style directives'] = 'Οδηγίες πρόσθετου στυλ';
L10n::$locales['All keywords'] = 'Όλες οι λέξεις κλειδιά';
L10n::$locales['Archives'] = 'Αρχειοθέτηση';
L10n::$locales['Attachments'] = 'Συνημμένα';
L10n::$locales['Best of me'] = 'Καλύτερο από μένα';
L10n::$locales['Blog info'] = 'Πληροφορίες ιστολογίου';
L10n::$locales['Blog menu'] = 'μενού ιστολογίου';
L10n::$locales['By'] = 'Από';
L10n::$locales['By category'] = 'Κατά κατηγορία';
L10n::$locales['By date'] = 'Κατά ημερομηνία';
L10n::$locales['By tag'] = 'Με ετικέτα';
L10n::$locales['Categories'] = 'Κατηγορίες';
L10n::$locales['Comment'] = 'Σχόλιο';
L10n::$locales['Comments'] = 'Σχόλια';
L10n::$locales['Comments can be formatted using a simple wiki syntax.'] = 'Σχόλια μπορούν να μορφοποιηθούν χρησιμοποιώντας μια απλή σύνταξη wiki.';
L10n::$locales['Comments feed'] = 'Ροή σχολίων';
L10n::$locales['Continue reading'] = 'Συνέχεια ανάγνωσης';
L10n::$locales['Document not found'] = 'Το έγγραφο δεν βρέθηκε';
L10n::$locales['Email address'] = 'Διεύθυνση ηλεκτρονικού ταχυδρομείου';
L10n::$locales['Email address is not valid'] = 'Η διεύθυνση ηλεκτρονικού ταχυδρομείου δεν είναι έγκυρη';
L10n::$locales['Entries feed'] = 'Τροφοδοσία καταχωρήσεων';
L10n::$locales['Explore archives'] = 'Εξερεύνηση αρχείων';
L10n::$locales['Extra menu'] = 'Extra menu';
L10n::$locales['Fields followed by * are mandatory'] = 'Τα πεδία που ακολουθούνται από * είναι υποχρεωτικά';
L10n::$locales['From'] = 'Από';
L10n::$locales['FromDay'] = 'FromDay';
L10n::$locales['Go to homepage'] = 'Μετάβαση στην αρχική σελίδα';
L10n::$locales['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML κωδικός εμφανίζεται ως κείμενο και διευθύνσεις web μετατρέπονται αυτόματα.';
L10n::$locales['Home'] = 'Αρχική';
L10n::$locales['In'] = 'Σε';
L10n::$locales['Languages'] = 'Γλώσσες';
L10n::$locales['Links'] = 'Σύνδεσμοι';
L10n::$locales['Name or nickname'] = 'Όνομα ή ψευδώνυμο';
L10n::$locales['Next entry:'] = 'Επόμενη καταχώρηση:';
L10n::$locales['On'] = 'Ενεργό';
L10n::$locales['Page top'] = 'Κορυφή σελίδας';
L10n::$locales['Pagination'] = 'Σελιδοποίηση';
L10n::$locales['Password needed'] = 'Απαιτείται κωδικός πρόσβασης';
L10n::$locales['Password:'] = 'Κωδικός:';
L10n::$locales['Permalink'] = 'Permalink';
L10n::$locales['Powered by %s'] = 'Τροφοδοτείται από %s';
L10n::$locales['Preview'] = 'Προεπισκόπηση';
L10n::$locales['Previous entry:'] = 'Προηγούμενη καταχώριση:';
L10n::$locales['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'RSS feed είναι μια δωρεάν περίληψη ιστολογίου. Παρέχει περιεχόμενο (δημοσιεύσεις ή σχόλια) ή περιλήψεις περιεχομένου, μαζί με συνδέσμους προς τις πλήρεις εκδόσεις και άλλα μεταδεδομένα. Τα τελευταία δημοσιευμένα στοιχεία μπορούν να διαβαστούν από το αγαπημένο σας RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.';
L10n::$locales['Read'] = 'Ανάγνωση';
L10n::$locales['Remember me on this blog'] = 'Να με θυμάσαι σε αυτό το blog';
L10n::$locales['Required field'] = 'Απαιτούμενο πεδίο';
L10n::$locales['Search'] = 'Αναζήτηση';
L10n::$locales['Send'] = 'Αποστολή';
L10n::$locales['Simply copy the following URL into your aggregator:'] = 'Απλά αντιγράψτε το ακόλουθο URL στον συγκεντρωτή σας:';
L10n::$locales['Subcategories'] = 'Υποκατηγορίες';
L10n::$locales['Subscribe'] = 'Εγγραφή';
L10n::$locales['Subscribe to'] = 'Εγγραφή σε';
L10n::$locales['Suggestions:'] = 'Προτείνες:';
L10n::$locales['The document you are looking for does not exist.'] = 'Το έγγραφο που ψάχνετε δεν υπάρχει.';
L10n::$locales['The list of recents posts is available'] = 'Η λίστα των πρόσφατων δημοσιεύσεων είναι διαθέσιμη';
L10n::$locales['They posted on the same topic'] = 'Δημοσίευσαν στο ίδιο θέμα';
L10n::$locales['This blog\'s comments Atom feed'] = 'Σχόλια αυτού του ιστολογίου';
L10n::$locales['This category\'s comments Atom feed'] = 'Σχόλια αυτής της κατηγορίας Ροή Atom';
L10n::$locales['This category\'s entries Atom feed'] = 'Οι καταχωρήσεις αυτής της κατηγορίας Atom';
L10n::$locales['This post\'s comments Atom feed'] = 'Σχόλια αυτής της ανάρτησης';
L10n::$locales['This post\'s comments feed'] = 'Ροή σχολίων αυτής της ανάρτησης';
L10n::$locales['To content'] = 'Προς περιεχόμενο';
L10n::$locales['To menu'] = 'Στο μενού';
L10n::$locales['To search'] = 'Για αναζήτηση';
L10n::$locales['Trackback URL'] = 'Url Παρακολούθησης';
L10n::$locales['URL you\'ve tried has typos, or the page has been deleted or moved.'] = 'URL που δοκιμάσατε έχει typos, ή η σελίδα έχει διαγραφεί ή μετακινηθεί.';
L10n::$locales['Use search form'] = 'Χρήση φόρμας αναζήτησης';
L10n::$locales['Website'] = 'Ιστοσελίδα';
L10n::$locales['What is an RSS feed?'] = 'Τι είναι ένα RSS feed?';
L10n::$locales['You must give a password to access this area.'] = 'Πρέπει να δώσετε έναν κωδικό πρόσβασης για να αποκτήσετε πρόσβαση σε αυτήν την περιοχή.';
L10n::$locales['You must provide a comment'] = 'Πρέπει να δώσετε ένα σχόλιο';
L10n::$locales['You must provide a valid email address.'] = 'Πρέπει να δώσετε μια έγκυρη διεύθυνση email.';
L10n::$locales['You must provide an author name'] = 'Πρέπει να δώσετε ένα όνομα συγγραφέα';
L10n::$locales['Your comment'] = 'Το σχόλιό σας';
L10n::$locales['Your comment has been published.'] = 'Το σχόλιό σας έχει δημοσιευτεί.';
L10n::$locales['Your comment has been submitted and will be reviewed for publication.'] = 'Το σχόλιό σας έχει υποβληθεί και θα επανεξεταστεί για δημοσίευση.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Η αναζήτησή σας για <em>%1$s</em> επέστρεψε <strong>%2$s</strong> αποτέλεσμα.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Η αναζήτησή σας για <em>%1$s</em> επέστρεψε <strong>%2$s</strong> αποτελέσματα.';
L10n::$locales['Your search for <em>%1$s</em> returned no result.'] = 'Η αναζήτησή σας για <em>%1$s</em> δεν επέστρεψε κανένα αποτέλεσμα.';
L10n::$locales['by'] = 'από';
L10n::$locales['here'] = 'εδώ';
L10n::$locales['in'] = 'σε';
L10n::$locales['next entries'] = 'επόμενες καταχωρήσεις';
L10n::$locales['no attachments'] = 'δεν υπάρχουν συνημμένα';
L10n::$locales['no comments'] = 'κανένα σχόλιο';
L10n::$locales['no reactions'] = 'δεν υπάρχουν αντιδράσεις';
L10n::$locales['no trackbacks'] = 'δεν υπάρχουν ίχνη';
L10n::$locales['of'] = 'από';
L10n::$locales['on'] = 'ενεργό';
L10n::$locales['one attachment'] = 'ένα συνημμένο';
L10n::$locales['one comment'] = 'ένα σχόλιο';
L10n::$locales['one reaction'] = 'μία αντίδραση';
L10n::$locales['one trackback'] = 'ένα trackback';
L10n::$locales['optional'] = 'προαιρετικό';
L10n::$locales['page'] = 'σελίδα';
L10n::$locales['preview'] = 'προεπισκόπηση';
L10n::$locales['previous entries'] = 'προηγούμενες καταχωρήσεις';
L10n::$locales['reactions'] = 'αντιδράσεις';
L10n::$locales['send'] = 'αποστολή';
L10n::$locales['toDay'] = 'toDay';
